@@ -1,7 +1,11 @@
+# Copyrights 1999,2001-2007 by Mark Overmeer.
+#  For other contributors see ChangeLog.
+# See the manual pages for details on the licensing terms.
+# Pod stripped from pm file by OODoc 1.03.
 
 package MIME::Types;
 use vars '$VERSION';
-$VERSION = '1.15';
+$VERSION = '1.22';
 
 use strict;
 
@@ -9,9 +13,6 @@ use MIME::Type ();
 use Carp;
 
 
-#-------------------------------------------
-
-
 my %list;
 sub new(@) { (bless {}, shift)->init( {@_} ) }
 
@@ -42,7 +43,7 @@ sub init($)
 
             next if $args->{only_complete} && ! $extensions;
             my $extent = $extensions ? [ split /\,/, $extensions ] : undef;
-                    
+
             my $simplified = MIME::Type->simplified($type);
             push @{$list{$simplified}}, MIME::Type->new
               ( type       => $type
@@ -126,7 +127,7 @@ sub types
     $self->create_type_index unless keys %type_index;
     return values %type_index;
 }
-                                                                                
+
 #-------------------------------------------
 
 
@@ -136,7 +137,7 @@ sub extensions
 
     return keys %type_index;
 }
-                                                                                
+
 #-------------------------------------------
 
 
@@ -203,15 +204,15 @@ CROAK
 
 #-------------------------------------------
 # Internet media type registry is at
-# <http://www.iana.org/assignments/media-types/> and
-# F<ftp://ftp.iana.org/in-notes/iana/assignments/media-types/>.
+# http://www.iana.org/assignments/media-types/
 
-$mime_type_definitions = <<MIMETYPES;
+$mime_type_definitions = <<__MIMETYPES__;
 application/activemessage
 application/andrew-inset		ez
 application/appledouble					base64
 application/applefile					base64
 application/atomicmail
+application/atom+xml			atom		8bit
 application/batch-SMTP
 application/beep+xml
 application/cals-1840
@@ -223,6 +224,7 @@ application/DCA-RFT
 application/DEC-DX
 application/dicom
 application/dvcs
+application/ecmascript
 application/EDI-Consent
 application/EDIFACT
 application/EDI-X12
@@ -239,6 +241,7 @@ application/index.vnd
 application/iotp
 application/ipp
 application/isup
+application/javascript		js				8bit
 application/mac-binhex40	hqx				8bit
 application/macwriteii
 application/marc
@@ -248,7 +251,7 @@ application/news-message-id
 application/news-transmission
 application/ocsp-request	orq
 application/ocsp-response	ors
-application/octet-stream	bin,dms,lha,lzh,exe,class,ani,pgp	base64
+application/octet-stream bin,dms,lha,lzh,exe,class,ani,pgp,so,dll,dmg	base64
 application/oda			oda
 application/ogg			ogg
 application/parityfec
@@ -271,6 +274,7 @@ application/prs.cww		cw,cww
 application/prs.nprend		rnd,rct
 application/prs.plucker
 application/qsig
+application/rdf+xml		rdf				8bit
 application/reginfo+xml
 application/remote-printing
 application/riscos
@@ -284,7 +288,7 @@ application/sgml
 application/sgml-open-catalog	soc
 application/sieve		siv
 application/slate
-application/smil		smi,smil
+application/smil		smi,smil			8bit
 application/timestamp-query
 application/timestamp-reply
 application/toolbook		tbk
@@ -369,7 +373,7 @@ application/vnd.groove-tool-template
 application/vnd.groove-vcard
 application/vnd.hbci		hbci,hbc,kom,upa,pkd,bpd
 application/vnd.hhe.lesson-player	les
-application/vnd.hp-HPGL		plt,hpgl	
+application/vnd.hp-HPGL		plt,hpgl
 application/vnd.hp-hpid
 application/vnd.hp-hps
 application/vnd.hp-PCL
@@ -411,6 +415,8 @@ application/vnd.kde.kword	kwd,kwt
 application/vnd.kenameapp	htke
 application/vnd.kidspiration	kia
 application/vnd.Kinar		kne,knp,sdf
+application/vnd.google-earth.kml+xml			kml	8bit
+application/vnd.google-earth.kmz			kmz	8bit
 application/vnd.koan
 application/vnd.liberty-request+xml
 application/vnd.llamagraphics.life-balance.desktop	lbd
@@ -596,7 +602,7 @@ application/x-dxf
 application/x-excel
 application/x-fractals
 application/x-futuresplash	spl
-application/x-ghostview		
+application/x-ghostview
 application/x-gtar		gtar,tgz,tbz2,tbz		base64
 application/x-gunzip
 application/x-gzip		gz				base64
@@ -610,7 +616,6 @@ application/x-ideas
 application/x-imagemap		imagemap,imap			8bit
 application/x-java-archive	jar
 application/x-java-jnlp-file	jnlp
-application/x-javascript	js				8bit
 application/x-java-serialized-object	ser
 application/x-java-vm		class
 application/x-koan		skp,skd,skt,skm
@@ -620,8 +625,8 @@ application/x-mac-compactpro	cpt
 application/x-maker		frm,maker,frame,fm,fb,book,fbdoc
 application/x-mathcad	# mcd, but there is also vnd.mcd
 application/x-mif		mif
-application/xml
-application/xml-dtd
+application/xml			xml xsl				8bit
+application/xml-dtd		dtd				8bit
 application/xml-external-parsed-entity
 application/x-msaccess			mda,mdb,mde,mdf		base64
 application/x-msdos-program	cmd,bat				8bit
@@ -642,6 +647,7 @@ application/x-set
 application/x-shar		shar				8bit
 application/x-shockwave-flash	swf
 application/x-sh		sh				8bit
+application/xslt+xml		xslt				8bit
 application/x-SLA
 application/x-solids
 application/x-spss		sav,sbs,sps,spo,spp
@@ -667,7 +673,8 @@ application/x-x400-bp
 application/x-x509-ca-cert	crt				base64
 application/zip			zip				base64
 audio/32kadpcm
-audio/3gpp			3gpp
+audio/3gpp
+audio/3gpp2
 audio/AMR			amr				base64
 audio/AMR-WB			awb				base64
 audio/basic			au,snd				base64
@@ -727,7 +734,7 @@ audio/vnd.nuera.ecelp4800	ecelp4800
 audio/vnd.nuera.ecelp7470	ecelp7470
 audio/vnd.nuera.ecelp9600	ecelp9600
 audio/vnd.octel.sbc
-audio/vnd.qcelp	
+audio/vnd.qcelp
 audio/vnd.rhetorex.32kadpcm
 audio/vnd.sealedmedia.softseal.mpeg	smp3,smp,s1m
 audio/vnd.vmx.cvsd
@@ -744,7 +751,7 @@ image/cgm
 image/g3fax
 image/gif			gif				base64
 image/ief			ief				base64
-image/jp2			jp2,jpg2
+image/jp2			jp2,jpg2			base64
 image/jpeg			jpeg,jpg,jpe			base64
 image/jpm			jpm,jpgm
 image/jpx			jpf,jpx
@@ -752,6 +759,7 @@ image/naplps
 image/png			png				base64
 image/prs.btif
 image/prs.pti
+image/svg+xml			svg				8bit
 image/t38
 image/targa			tga
 image/tiff-fx
@@ -830,7 +838,8 @@ multipart/x-ustar
 multipart/x-www-form-urlencoded
 multipart/x-zip
 text/calendar
-text/comma-separated-values		csv				8bit
+text/csv				csv				8bit
+text/comma-separated-values						8bit
 text/css				css				8bit
 text/directory
 text/enriched
@@ -866,12 +875,13 @@ text/vnd.wap.sl				sl
 text/vnd.wap.wmlscript			wmls
 text/vnd.wap.wml			wml
 text/xml-external-parsed-entity
-text/xml				xml,dtd				8bit
+text/xml
 text/x-setext				etx
 text/x-sgml				sgml,sgm			8bit
 text/x-vCalendar			vcs				8bit
 text/x-vCard				vcf				8bit
-video/3gpp				3gp,3gpp
+video/3gpp				3gp,3gpp			base64
+video/3gpp2				3g2,3gpp2			base64
 video/BMPEG
 video/BT656
 video/CelB
@@ -908,6 +918,7 @@ video/vnd.sealed.mpeg4			smpg,s14
 video/vnd.sealed.swf			sswf,ssw
 video/vnd.vivo				viv,vivo
 video/x-fli				fli				base64
+video/x-flv				flv				base64
 video/x-ms-asf				asf,asx
 video/x-ms-wmv				wmv
 video/x-msvideo				avi				base64
@@ -923,6 +934,9 @@ x-world/x-vrml				wrl,vrml
 vms:text/plain				doc				8bit
 mac:application/x-macbase64		bin
 
-MIMETYPES
+# IE6 bug
+image/pjpeg								base64
+
+__MIMETYPES__
 
 1;
